from __future__ import annotations
import numpy as np
import numpy.testing as nptst
from esrimap import EsriAscii, EsriCoordinateType
from PIL import Image
import requests
from typing import Tuple


def build_req_body(map: EsriAscii, taglist: list):
    arucos = []
    for t in taglist:
        (x,y), id = t
        arucos.append({
            "tag_id": id,
            "position": {
                "x": x,
                "y": y
            }
        })
    body = {
        "esri": map.to_ascii(),
        "arucos": arucos
    }
    return body


def send_req(body, url="http://localhost:8000/map"):
    requests.post(url, json=body)


if __name__=="__main__":
    # esri_map = EsriAscii(10, 20, data_array=None, coord_type=EsriCoordinateType.corner)
    array = np.arange(0, 20*30).reshape((20, 30))
    # im = Image.open("test.png")
    the_map = EsriAscii.from_ndarray(array)
    array[0, 0] = 99999
    print(the_map)
    nptst.assert_array_equal(the_map.data, array, verbose=True)

    fake_arucos = [((30, 30), 0), ((255, 255), 21)]
    send_req(build_req_body(the_map, fake_arucos))
